==> 0.0.7.tar.gz: lib/sprig_web.dart <==
import 'dart:async';

// In order to *not* need this ignore, consider extracting the "web" version
// of your plugin as a separate package, instead of inlining it in the same
// package as the core of your plugin.
// ignore: avoid_web_libraries_in_flutter

import 'package:flutter/services.dart';
import 'package:flutter_web_plugins/flutter_web_plugins.dart';
import 'package:sprig_platform_interface/sprig_platform_interface.dart';
import 'package:sprig_platform_interface/channels.dart';

import 'sprig_js_bindings.dart' as sprig;

/// A web implementation of the UserleapFlutterWeb plugin.
class SprigWeb implements SprigPlatform {
  static void registerWith(Registrar registrar) {
    /*final MethodChannel channel = MethodChannel(
      Channels.CHANNEL,
      const StandardMethodCodec(),
      registrar,
    );*/

    //channel.setMethodCallHandler(pluginInstance.handleMethodCall);
    SprigPlatform.instance = SprigWeb();
  }

  // final userLeap = html.window.userLeap;

  /// Handles method calls over the MethodChannel of this plugin.
  /// Note: Check the "federated" architecture for a new way of doing this:
  /// https://flutter.dev/go/federated-plugins
/*  Future<dynamic> handleMethodCall(MethodCall call) async {
    switch (call.method) {
      case Channels.CONFIGURE:
        //Web does not support this
        //configure(call.arguments['env']);
        return Channels.CONFIGURE;
      case Channels.DISPLAY_WITH_ID:
        sprig.displaySurvey(call.arguments['id']);
        return 'displaying survey';
      case Channels.LOGOUT:
        sprig.logoutUser();
        return 'logged out user succesfully';
      case Channels.PRESENT_DEBUG_SURVEY:
        sprig.track('1');
        return 'UNKNOWN';
      case Channels.SET_EMAIL_ADDRESS:
        sprig.setEmail(call.arguments['email']);
        return 'email address set succesfully';
      case Channels.SET_VISITOR_ATTRIBUTE:
        sprig.setAttribute(call.arguments['key'], call.arguments['value']);
        return 'set visitor attribute';
      case Channels.SET_USER_IDENTIFIER:
        sprig.setUserId(call.arguments['userId']);
        return 'set user ID';
      case Channels.TRACK:
        sprig.track(call.arguments['event']);
        return 'track user event: ${call.arguments['event']}';

      default:
        throw PlatformException(
          code: 'Unimplemented',
          details:
              'userleap_flutter_web for web doesn\'t implement \'${call.method}\'',
        );
    }
  } */

  /// Returns a [String] containing the version of the platform.
  Future<String> getPlatformVersion() {
    return Future.value("1");
  }

  @override
  Future configure(String environmentId) {
    // TODO: implement configure
    throw UnimplementedError(
        "configure is not supported on web. Add the Sprig script "
        "and parse your EnviromentID.");
  }

  @override
  Future displaySurveyWithId(int id) async {
    sprig.displaySurvey("$id");
  }

  @override
  // TODO: implement isPluginInitialized
  bool get isPluginInitialized => SprigPlatform.instance.isPluginInitialized;

  @override
  Future logout() async {
    sprig.logoutUser();
  }

  @override
  Future presentDebugSurvey() async {
    track("1");
  }

  @override
  Future setEmailAddress(String email) async {
    sprig.setEmail(email);
  }

  @override
  Future setUserIdentifier(String userId) async {
    sprig.setUserId(userId);
  }

  @override
  Future setVisitorAttribute(String key, String value) async {
    sprig.setAttribute(key, value);
  }

  @override
  Future<SurveryStatus> track(String event) async {
    sprig.track(event);
    return SurveryStatus.ready;
  }
}

==> 0.0.8.tar.gz: lib/sprig_web.dart <==
import 'dart:async';

// In order to *not* need this ignore, consider extracting the "web" version
// of your plugin as a separate package, instead of inlining it in the same
// package as the core of your plugin.
// ignore: avoid_web_libraries_in_flutter

import 'package:flutter_web_plugins/flutter_web_plugins.dart';
import 'package:sprig_platform_interface/sprig_platform_interface.dart';

import 'sprig_js_bindings.dart' as sprig;

/// A web implementation of the UserleapFlutterWeb plugin.
class SprigWeb extends SprigPlatform {
  static void registerWith(Registrar registrar) {
    SprigPlatform.instance = SprigWeb();
  }

  bool _isPluginInitialized = false;

  @override
  Future configure(String environmentId) async {
    _isPluginInitialized = true;
    return "configure";
  }

  @override
  Future displaySurveyWithId(int id) async {
    sprig.displaySurvey("$id");
    return "displaySurvey";
  }

  @override
  bool get isPluginInitialized => _isPluginInitialized;

  @override
  Future logout() async {
    sprig.logoutUser();
    return "logoutUser";
  }

  @override
  Future presentDebugSurvey() async {
    track("1");
    return "presentDebugSurvey";
  }

  @override
  Future setEmailAddress(String email) async {
    sprig.setEmail(email);
    return "Set email";
  }

  @override
  Future setUserIdentifier(String userId) async {
    sprig.setUserId(userId);
    return "setUserId";
  }

  @override
  Future setVisitorAttribute(String key, String value) async {
    sprig.setAttribute(key, value);
    return "setAttribute";
  }

  @override
  Future<SurveryStatus> track(String event) async {
    sprig.track(event);
    return SurveryStatus.ready;
  }
}
